# -*- coding: utf-8 -*-

from django.conf.urls import patterns, url
from django.conf import settings as conf
from django.contrib.auth.decorators import login_required
from rgallery.views import (Photos,
                            PhotosFolder,
                            PhotoDelete,
                            PhotoAdd,
                            PhotosTag,
                            PhotoAddTag,
                            PhotoGetVideo,
                            PhotoChangeStatus,
                            PhotoDownload,
                            PhotoMkThumb,
                            PhotoMediaSync)


########## PRIVACY SETTINGS
def private(myview):
    if conf.RGALLERY_PRIVATE:
        return login_required(myview)
    return myview
########## PRIVACY SETTINGS


########## URL SETTINGS
urlpatterns = patterns(
    '',

    url(r'^$',
        private(Photos.as_view()),
        name='index'),

    url(r'^page/(?P<page>\d+)/$',
        private(Photos.as_view()),
        name='page'),

    url(r'^photo/del/$',
        private(PhotoDelete.as_view()),
        name='photo_del'),

    url(r'^photo/add/$',
        private(PhotoAdd.as_view()),
        name='photo_add'),

    url(r'^photo/changestatus/$',
        private(PhotoChangeStatus.as_view()),
        name='photo_change_status'),

    url(r'^photo/download/$',
        private(PhotoDownload.as_view()),
        name='photo_download'),

    url(r'^photos/tag/(?P<slug>[-\w]+)/$',
        private(PhotosTag.as_view()),
        name='photos_tag'),

    url(r'^photos/tag/(?P<slug>[-\w]+)/(?P<page>\d+)/$',
        private(PhotosTag.as_view()),
        name='photos_tag_page'),

    url(r'^photo/add/tag/$',
        private(PhotoAddTag.as_view()),
        name='photo_add_tag'),

    url(r'^photo/get_video/$',
        private(PhotoGetVideo.as_view()),
        name='photo_get_video'),

    url(r'^(?P<folder>[-_A-Za-z0-9]+)/$',
        private(PhotosFolder.as_view()),
        name='folder'),

    url(r'^gallery/photos/mkthumb/$',
        private(PhotoMkThumb.as_view()),
        name='photo_mkthumb'),
    url(r'^gallery/photos/mediasync/$',
        private(PhotoMediaSync.as_view()),
        name='photo_mediasync'),
)
########## URL SETTINGS



#!/usr/bin/env python
# -*- coding: utf-8 -*-

from django.core.management.base import BaseCommand
from django.template import Context, Template
from django.conf import settings as conf
from sorl.thumbnail import get_thumbnail

import rgallery.models as mymodels
from utils import *


# Class MUST be named 'Command'
class Command(BaseCommand):

    # Displayed from 'manage.py help mycommand'
    help = """
    Tool that regenerate the image cache for all the photos:

    ./manage.py mkthumb

    To run this script from a crontab task we should do something like this:

    */30 * * * * cd /path/to/rgallery-project/ ; source env/bin/activate ; \
                 cd src ; python manage.py mkthumb > /dev/null

    """

    def handle(self, *app_labels, **options):
        """
        The command itself
        """

        print ""
        print "-"*80
        print ""
        print "[***] Making missing thumbs"
        print ""
        thumbs = conf.RGALLLERY_THUMBS
        conf.THUMBNAIL_DEBUG = True
        allphotos = mymodels.Photo.objects.all()
        for i, p in enumerate(allphotos):
            print "%04d - %s" % (i, p)
            for thumb in thumbs:
                c = Context({'image': p, 'thumb': "%sx%s" % (thumb, thumb)})
                t = Template('{% load thumbnail %}{% thumbnail image thumb \
                              crop="top" as img %}{{ img.url }}\
                              {% endthumbnail %}')
                t.render(c)
                get_thumbnail(p, "%sx%s" % (thumb, thumb))

        print ""
        print "-"*80
        print ""
        print "[***] Done"
        print ""
        print "-"*80



# -*- coding: utf-8 -*-
from setuptools import setup, find_packages

setup(
    name='django-rgallery',
    version='1.8.0',  # New branch adapted to Django 1.8
    author=u'Oscar M. Lage Guitian',
    author_email='info@oscarmlage.com',
    packages=find_packages(),
    include_package_data=True,
    package_data={'': ['rgallery/templates',
                       'rgallery/static',
                       'rgallery/management']},
    url='http://bitbucket.org/r0sk/django-rgallery',
    license='BSD licence, see LICENSE file',
    description='Yet another Django Gallery App',
    zip_safe=False,
    long_description=open('README.rst').read(),
    install_requires=[
        "Django < 1.9",
        "Pillow",
        "exifread",
        "django-braces",
        "django-rmixins",
        "sorl-thumbnail == 11.12.1b",  # this version fixes the problem
                                       # importing simplejson from django
        "django_compressor",
        "dropbox",
        "django-taggit",
        "BeautifulSoup",
    ],
    keywords="django application gallery",
    classifiers=[
        'Development Status :: 4 - Beta',
        'Environment :: Web Environment',
        'Framework :: Django',
        'Intended Audience :: Developers',
        'License :: OSI Approved :: BSD License',
        'Operating System :: OS Independent',
        'Programming Language :: Python',
        'Topic :: Internet :: WWW/HTTP :: Dynamic Content',
        'Topic :: Software Development :: Libraries :: Python Modules',
    ],
)



# -*- coding: utf-8 -*-
from __future__ import unicode_literals

from django.db import models, migrations
import taggit.managers


class Migration(migrations.Migration):

    dependencies = [
        ('taggit', '0001_initial'),
    ]

    operations = [
        migrations.CreateModel(
            name='Folder',
            fields=[
                ('id', models.AutoField(verbose_name='ID', serialize=False, auto_created=True, primary_key=True)),
                ('title', models.CharField(max_length=255, verbose_name='Title')),
                ('slug', models.SlugField(unique=True, max_length=255, verbose_name='Slug')),
                ('password', models.CharField(default=b'', max_length=255, null=True, verbose_name='Password', blank=True)),
                ('status', models.BooleanField(default=True, verbose_name='Status')),
            ],
            options={
                'verbose_name': 'Folder',
                'verbose_name_plural': 'Folders',
            },
        ),
        migrations.CreateModel(
            name='Photo',
            fields=[
                ('id', models.AutoField(verbose_name='ID', serialize=False, auto_created=True, primary_key=True)),
                ('title', models.CharField(max_length=255, null=True, verbose_name='Title', blank=True)),
                ('image', models.ImageField(upload_to=b'uploads/photos/', verbose_name='Image', blank=True)),
                ('video', models.FileField(upload_to=b'uploads/videos/', null=True, verbose_name='Video', blank=True)),
                ('origen', models.CharField(max_length=255, verbose_name='Source file')),
                ('insert_date', models.DateTimeField(verbose_name='Insert date')),
                ('capture_date', models.DateTimeField(verbose_name='Photo date')),
                ('status', models.BooleanField(default=True, verbose_name='Status')),
                ('folder', models.ForeignKey(related_name='photo', verbose_name='Folder', blank=True, to='rgallery.Folder', null=True)),
                ('tags', taggit.managers.TaggableManager(to='taggit.Tag', through='taggit.TaggedItem', blank=True, help_text='A comma-separated list of tags.', verbose_name='Tags')),
            ],
            options={
                'verbose_name': 'Photo',
                'verbose_name_plural': 'Photos',
            },
        ),
    ]
